@@ -1,43 +1,38 @@
 
 # -*- coding: utf-8 -*-
 """
-The py lib is a development support library featuring these tools and APIs:
+advanced testing and development support library: 
 
 - `py.test`_: cross-project testing tool with many advanced features
 - `py.execnet`_: ad-hoc code distribution to SSH, Socket and local sub processes
-- `py.magic.greenlet`_: micro-threads on standard CPython ("stackless-light") and PyPy
 - `py.path`_: path abstractions over local and subversion files 
 - `py.code`_: dynamic code compile and traceback printing support
 
-The py lib and its tools should work well on Linux, Win32, 
-OSX, Python versions 2.3-2.6.  For questions please go to
-http://pylib.org/contact.html
+Compatibility: Linux, Win32, OSX, Python versions 2.3-2.6. 
+For questions please check out http://pylib.org/contact.html
 
 .. _`py.test`: http://pylib.org/test.html
 .. _`py.execnet`: http://pylib.org/execnet.html
-.. _`py.magic.greenlet`: http://pylib.org/greenlet.html
 .. _`py.path`: http://pylib.org/path.html
 .. _`py.code`: http://pylib.org/code.html
  
 """
 from initpkg import initpkg
+trunk = None
 
-version = "0.9.2"
+version = trunk or "1.0.0"
 
 initpkg(__name__,
-    description = "py lib: agile development and test support library",
-    revision = int('$LastChangedRevision: 57579 $'.split(':')[1][:-1]),
-    lastchangedate = '$LastChangedDate: 2008-08-22 12:37:35 +0200 (Fri, 22 Aug 2008) $',
+    description = "py.test and pylib: advanced testing tool and networking lib", 
     version = version, 
     url = "http://pylib.org", 
-    download_url = "http://codespeak.net/py/0.9.2/download.html",
     license = "MIT license",
     platforms = ['unix', 'linux', 'osx', 'cygwin', 'win32'],
     author = "holger krekel, Guido Wesdorp, Carl Friedrich Bolz, Armin Rigo, Maciej Fijalkowski & others",
     author_email = "holger at merlinux.eu, py-dev at codespeak.net",
     long_description = globals()['__doc__'],
     classifiers = [
-        "Development Status :: 4 - Beta",
+        "Development Status :: 5 - Production/Stable", 
         "Intended Audience :: Developers", 
         "License :: OSI Approved :: MIT License",
         "Operating System :: POSIX",
@@ -50,23 +45,32 @@ initpkg(__name__,
         "Programming Language :: Python",
     ],
 
-
     # EXPORTED API 
     exportdefs = {
+
+    # py lib events and plugins 
+    '_com.Registry'          : ('./_com.py', 'Registry'), 
+    '_com.MultiCall'         : ('./_com.py', 'MultiCall'), 
+    '_com.comregistry'       : ('./_com.py', 'comregistry'), 
+    '_com.Hooks'             : ('./_com.py', 'Hooks'), 
+
     # py lib cmdline tools 
     'cmdline.pytest'         : ('./cmdline/pytest.py', 'main',),
     'cmdline.pyrest'         : ('./cmdline/pyrest.py', 'main',),
     'cmdline.pylookup'       : ('./cmdline/pylookup.py', 'main',),
     'cmdline.pycountloc'     : ('./cmdline/pycountloc.py', 'main',),
     'cmdline.pycleanup'      : ('./cmdline/pycleanup.py', 'main',),
+    'cmdline.pywhich'        : ('./cmdline/pywhich.py', 'main',),
+    'cmdline.pysvnwcrevert'  : ('./cmdline/pysvnwcrevert.py', 'main',),
 
     # helpers for use from test functions or collectors
     'test.__doc__'           : ('./test/__init__.py', '__doc__'),
-    'test.raises'            : ('./test/raises.py', 'raises'),
-    'test.deprecated_call'   : ('./test/deprecate.py', 'deprecated_call'), 
-    'test.skip'              : ('./test/item.py', 'skip'),
-    'test.fail'              : ('./test/item.py', 'fail'),
-    'test.exit'              : ('./test/session.py', 'exit'),
+    'test._PluginManager'    : ('./test/pluginmanager.py', 'PluginManager'),
+    'test.raises'            : ('./test/outcome.py', 'raises'),
+    'test.skip'              : ('./test/outcome.py', 'skip'),
+    'test.importorskip'      : ('./test/outcome.py', 'importorskip'),
+    'test.fail'              : ('./test/outcome.py', 'fail'),
+    'test.exit'              : ('./test/outcome.py', 'exit'),
 
     # configuration/initialization related test api
     'test.config'            : ('./test/config.py', 'config_per_process'),
@@ -76,13 +80,14 @@ initpkg(__name__,
     # for customization of collecting/running tests
     'test.collect.Collector' : ('./test/collect.py', 'Collector'),
     'test.collect.Directory' : ('./test/collect.py', 'Directory'),
-    'test.collect.Module'    : ('./test/collect.py', 'Module'),
-    'test.collect.DoctestFile' : ('./test/collect.py', 'DoctestFile'),
-    'test.collect.Class'     : ('./test/collect.py', 'Class'),
-    'test.collect.Instance'  : ('./test/collect.py', 'Instance'),
-    'test.collect.Generator' : ('./test/collect.py', 'Generator'),
-    'test.collect.Item'      : ('./test/item.py', 'Item'),
-    'test.collect.Function'  : ('./test/item.py', 'Function'),
+    'test.collect.File'      : ('./test/collect.py', 'File'),
+    'test.collect.Item'      : ('./test/collect.py', 'Item'),
+    'test.collect.Module'    : ('./test/pycollect.py', 'Module'),
+    'test.collect.Class'     : ('./test/pycollect.py', 'Class'),
+    'test.collect.Instance'  : ('./test/pycollect.py', 'Instance'),
+    'test.collect.Generator' : ('./test/pycollect.py', 'Generator'),
+    'test.collect.Function'  : ('./test/pycollect.py', 'Function'),
+    'test.collect._fillfuncargs' : ('./test/funcargs.py', 'fillfuncargs'),
 
     # thread related API (still in early design phase)
     '_thread.WorkerPool'      : ('./thread/pool.py', 'WorkerPool'),
@@ -94,6 +99,8 @@ initpkg(__name__,
 
     'process.__doc__'        : ('./process/__init__.py', '__doc__'),
     'process.cmdexec'        : ('./process/cmdexec.py', 'cmdexec'),
+    'process.kill'           : ('./process/killproc.py', 'kill'),
+    'process.ForkedFunc'     : ('./process/forkedfunc.py', 'ForkedFunc'), 
 
     # path implementation
     'path.__doc__'           : ('./path/__init__.py', '__doc__'),
@@ -104,7 +111,6 @@ initpkg(__name__,
 
     # some nice slightly magic APIs
     'magic.__doc__'          : ('./magic/__init__.py', '__doc__'),
-    'magic.greenlet'         : ('./magic/greenlet.py', 'greenlet'),
     'magic.invoke'           : ('./magic/invoke.py', 'invoke'),
     'magic.revoke'           : ('./magic/invoke.py', 'revoke'),
     'magic.patch'            : ('./magic/patch.py', 'patch'),
@@ -120,6 +126,7 @@ initpkg(__name__,
     'code.Frame'             : ('./code/frame.py', 'Frame'),
     'code.ExceptionInfo'     : ('./code/excinfo.py', 'ExceptionInfo'),
     'code.Traceback'         : ('./code/traceback2.py', 'Traceback'),
+    'code.getfslineno'       : ('./code/source.py', 'getfslineno'),
 
     # backports and additions of builtins
     'builtin.__doc__'        : ('./builtin/__init__.py', '__doc__'),
@@ -127,14 +134,20 @@ initpkg(__name__,
     'builtin.reversed'       : ('./builtin/reversed.py',  'reversed'),
     'builtin.sorted'         : ('./builtin/sorted.py',    'sorted'),
     'builtin.BaseException'  : ('./builtin/exception.py', 'BaseException'),
+    'builtin.GeneratorExit'  : ('./builtin/exception.py', 'GeneratorExit'),
     'builtin.set'            : ('./builtin/set.py',       'set'),
     'builtin.frozenset'      : ('./builtin/set.py',       'frozenset'),
 
     # gateways into remote contexts
     'execnet.__doc__'        : ('./execnet/__init__.py', '__doc__'),
+    'execnet._HookSpecs'           : ('./execnet/gateway.py', 'ExecnetAPI'),
     'execnet.SocketGateway'  : ('./execnet/register.py', 'SocketGateway'),
     'execnet.PopenGateway'   : ('./execnet/register.py', 'PopenGateway'),
     'execnet.SshGateway'     : ('./execnet/register.py', 'SshGateway'),
+    'execnet.XSpec'          : ('./execnet/xspec.py', 'XSpec'),
+    'execnet.makegateway'    : ('./execnet/xspec.py', 'makegateway'),
+    'execnet.MultiGateway'   : ('./execnet/multi.py', 'MultiGateway'),
+    'execnet.MultiChannel'   : ('./execnet/multi.py', 'MultiChannel'),
 
     # execnet scripts
     'execnet.RSync'          : ('./execnet/rsync.py', 'RSync'),
@@ -145,6 +158,7 @@ initpkg(__name__,
     'io.FDCapture'           : ('./io/fdcapture.py', 'FDCapture'), 
     'io.StdCapture'          : ('./io/stdcapture.py', 'StdCapture'), 
     'io.StdCaptureFD'        : ('./io/stdcapture.py', 'StdCaptureFD'), 
+    'io.TerminalWriter'      : ('./io/terminalwriter.py', 'TerminalWriter'), 
 
     # error module, defining all errno's as Classes
     'error'                  : ('./misc/error.py', 'error'),
@@ -159,6 +173,7 @@ initpkg(__name__,
 
     # logging API ('producers' and 'consumers' connected via keywords)
     'log.__doc__'            : ('./log/__init__.py', '__doc__'),
+    'log._apiwarn'            : ('./log/warning.py', '_apiwarn'),
     'log.Producer'           : ('./log/producer.py', 'Producer'),
     'log.default'            : ('./log/producer.py', 'default'),
     'log._getstate'          : ('./log/producer.py', '_getstate'),
@@ -178,3 +193,5 @@ initpkg(__name__,
     'compat.subprocess'      : ('./compat/subprocess.py', '*'),
 })
 
+
+
